@@ -1,6 +1,6 @@
 /*
  *  git2r, R bindings to the libgit2 library.
- *  Copyright (C) 2013-2019 The git2r contributors
+ *  Copyright (C) 2013-2024 The git2r contributors
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License, version 2,
@@ -16,10 +16,10 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include <R_ext/Visibility.h>
 #include <git2.h>
 
 #include "git2r_arg.h"
-#include "git2r_deprecated.h"
 #include "git2r_error.h"
 #include "git2r_S3.h"
 
@@ -29,7 +29,9 @@
  * @param arg the arg to check
  * @return 0 if OK, else -1
  */
-int git2r_arg_check_blob(SEXP arg)
+int attribute_hidden
+git2r_arg_check_blob(
+    SEXP arg)
 {
     if (!Rf_isNewList(arg) || !Rf_inherits(arg, "git_blob"))
         return -1;
@@ -46,7 +48,9 @@ int git2r_arg_check_blob(SEXP arg)
  * @param arg the arg to check
  * @return 0 if OK, else -1
  */
-int git2r_arg_check_branch(SEXP arg)
+int attribute_hidden
+git2r_arg_check_branch(
+    SEXP arg)
 {
     SEXP slot;
 
@@ -76,7 +80,9 @@ int git2r_arg_check_branch(SEXP arg)
  * @param arg the arg to check
  * @return 0 if OK, else -1
  */
-int git2r_arg_check_commit(SEXP arg)
+int attribute_hidden
+git2r_arg_check_commit(
+    SEXP arg)
 {
     if (!Rf_isNewList(arg) || !Rf_inherits(arg, "git_commit"))
         return -1;
@@ -93,7 +99,9 @@ int git2r_arg_check_commit(SEXP arg)
  * @param arg the arg to check
  * @return 0 if OK, else -1
  */
-int git2r_arg_check_commit_stash(SEXP arg)
+int attribute_hidden
+git2r_arg_check_commit_stash(
+    SEXP arg)
 {
     if (!Rf_isNewList(arg))
         return -1;
@@ -113,7 +121,9 @@ int git2r_arg_check_commit_stash(SEXP arg)
  * @param arg the arg to check
  * @return 0 if OK, else -1
  */
-int git2r_arg_check_credentials(SEXP arg)
+int attribute_hidden
+git2r_arg_check_credentials(
+    SEXP arg)
 {
     /* It's ok if the credentials is R_NilValue */
     if (Rf_isNull(arg))
@@ -179,7 +189,9 @@ int git2r_arg_check_credentials(SEXP arg)
  * @param arg the arg to check
  * @return 0 if OK, else -1
  */
-int git2r_arg_check_fetch_heads(SEXP arg)
+int attribute_hidden
+git2r_arg_check_fetch_heads(
+    SEXP arg)
 {
     const char *repo = NULL;
     size_t i,n;
@@ -219,7 +231,9 @@ int git2r_arg_check_fetch_heads(SEXP arg)
  * @param arg the arg to check
  * @return 0 if OK, else -1
  */
-int git2r_arg_check_filename(SEXP arg)
+int attribute_hidden
+git2r_arg_check_filename(
+    SEXP arg)
 {
     if (Rf_isNull(arg))
         return 0;
@@ -247,7 +261,9 @@ int git2r_arg_check_filename(SEXP arg)
  * @param arg the arg to check
  * @return 0 if OK, else -1
  */
-int git2r_arg_check_sha(SEXP arg)
+int attribute_hidden
+git2r_arg_check_sha(
+    SEXP arg)
 {
     size_t len;
 
@@ -267,7 +283,9 @@ int git2r_arg_check_sha(SEXP arg)
  * @param arg the arg to check
  * @return 0 if OK, else -1
  */
-int git2r_arg_check_integer(SEXP arg)
+int attribute_hidden
+git2r_arg_check_integer(
+    SEXP arg)
 {
     if (!Rf_isInteger(arg) || 1 != Rf_length(arg) || NA_INTEGER == INTEGER(arg)[0])
         return -1;
@@ -280,7 +298,9 @@ int git2r_arg_check_integer(SEXP arg)
  * @param arg the arg to check
  * @return 0 if OK, else -1
  */
-int git2r_arg_check_integer_gte_zero(SEXP arg)
+int attribute_hidden
+git2r_arg_check_integer_gte_zero(
+    SEXP arg)
 {
     if (git2r_arg_check_integer(arg))
         return -1;
@@ -295,7 +315,9 @@ int git2r_arg_check_integer_gte_zero(SEXP arg)
  * @param arg the arg to check
  * @return 0 if OK, else -1
  */
-int git2r_arg_check_list(SEXP arg)
+int attribute_hidden
+git2r_arg_check_list(
+    SEXP arg)
 {
     if (!Rf_isNewList(arg))
         return -1;
@@ -309,7 +331,9 @@ int git2r_arg_check_list(SEXP arg)
  * @param arg the arg to check
  * @return 0 if OK, else -1
  */
-int git2r_arg_check_logical(SEXP arg)
+int attribute_hidden
+git2r_arg_check_logical(
+    SEXP arg)
 {
     if (!Rf_isLogical(arg) || 1 != Rf_length(arg) || NA_LOGICAL == LOGICAL(arg)[0])
         return -1;
@@ -322,7 +346,9 @@ int git2r_arg_check_logical(SEXP arg)
  * @param arg the arg to check
  * @return 0 if OK, else -1
  */
-int git2r_arg_check_note(SEXP arg)
+int attribute_hidden
+git2r_arg_check_note(
+    SEXP arg)
 {
     if (!Rf_isNewList(arg) || !Rf_inherits(arg, "git_note"))
         return -1;
@@ -342,20 +368,45 @@ int git2r_arg_check_note(SEXP arg)
  * @param arg the arg to check
  * @return 0 if OK, else -1
  */
-int git2r_arg_check_real(SEXP arg)
+int attribute_hidden
+git2r_arg_check_real(
+    SEXP arg)
 {
     if (!Rf_isReal(arg) || 1 != Rf_length(arg) || !R_finite(REAL(arg)[0]))
         return -1;
     return 0;
 }
 
+/**
+ * Check proxy argument
+ * 
+ * proxy may be NULL, TRUE or a string
+ *
+ * @param arg the arg to check
+ * @return 0 if OK, else -1
+ */
+int attribute_hidden
+git2r_arg_check_proxy(
+    SEXP arg)
+{
+    if (Rf_isNull(arg))
+        return 0;
+    if (Rf_isLogical(arg) && 1 == Rf_length(arg) && NA_LOGICAL != LOGICAL(arg)[0])
+        return 0;
+    if (Rf_isString(arg) && 1 == Rf_length(arg) && NA_STRING != STRING_ELT(arg, 0))
+        return 0;
+    return -1;
+}
+
 /**
  * Check repository argument
  *
  * @param arg the arg to check
  * @return 0 if OK, else -1
  */
-int git2r_arg_check_repository(SEXP arg)
+int attribute_hidden
+git2r_arg_check_repository(
+    SEXP arg)
 {
     if (!Rf_isNewList(arg) || !Rf_inherits(arg, "git_repository"))
         return -1;
@@ -372,7 +423,10 @@ int git2r_arg_check_repository(SEXP arg)
  * @param arg the arg to check
  * @return 0 if OK, else -1
  */
-int git2r_arg_check_same_repo(SEXP arg1, SEXP arg2)
+int attribute_hidden
+git2r_arg_check_same_repo(
+    SEXP arg1,
+    SEXP arg2)
 {
     SEXP path1, path2;
 
@@ -393,7 +447,9 @@ int git2r_arg_check_same_repo(SEXP arg1, SEXP arg2)
  * @param arg the arg to check
  * @return 0 if OK, else -1
  */
-int git2r_arg_check_signature(SEXP arg)
+int attribute_hidden
+git2r_arg_check_signature(
+    SEXP arg)
 {
     SEXP when;
 
@@ -422,7 +478,9 @@ int git2r_arg_check_signature(SEXP arg)
  * @param arg the arg to check
  * @return 0 if OK, else -1
  */
-int git2r_arg_check_string(SEXP arg)
+int attribute_hidden
+git2r_arg_check_string(
+    SEXP arg)
 {
     if (git2r_arg_check_string_vec(arg) < 0)
         return -1;
@@ -439,7 +497,9 @@ int git2r_arg_check_string(SEXP arg)
  * @param arg the arg to check
  * @return 0 if OK, else -1
  */
-int git2r_arg_check_string_vec(SEXP arg)
+int attribute_hidden
+git2r_arg_check_string_vec(
+    SEXP arg)
 {
     if (!Rf_isString(arg))
         return -1;
@@ -454,7 +514,10 @@ int git2r_arg_check_string_vec(SEXP arg)
  * @return 0 if OK, else error code
  */
 
-int git2r_copy_string_vec(git_strarray *dst, SEXP src)
+int attribute_hidden
+git2r_copy_string_vec(
+    git_strarray *dst,
+    SEXP src)
 {
     size_t i, len;
 
@@ -471,7 +534,7 @@ int git2r_copy_string_vec(git_strarray *dst, SEXP src)
     /* Allocate the strings in dst */
     dst->strings = malloc(dst->count * sizeof(char*));
     if (!dst->strings) {
-        GIT2R_ERROR_SET_STR(GIT2R_ERROR_NONE, git2r_err_alloc_memory_buffer);
+        giterr_set_str(GIT_ERROR_NONE, git2r_err_alloc_memory_buffer);
         return GIT_ERROR;
     }
 
@@ -489,7 +552,9 @@ int git2r_copy_string_vec(git_strarray *dst, SEXP src)
  * @param arg the arg to check
  * @return 0 if OK, else -1
  */
-int git2r_arg_check_tag(SEXP arg)
+int attribute_hidden
+git2r_arg_check_tag(
+    SEXP arg)
 {
     if (!Rf_isNewList(arg) || !Rf_inherits(arg, "git_tag"))
         return -1;
@@ -506,7 +571,9 @@ int git2r_arg_check_tag(SEXP arg)
  * @param arg the arg to check
  * @return 0 if OK, else -1
  */
-int git2r_arg_check_tree(SEXP arg)
+int attribute_hidden
+git2r_arg_check_tree(
+    SEXP arg)
 {
     if (!Rf_isNewList(arg) || !Rf_inherits(arg, "git_tree"))
         return -1;
