@@ -27,7 +27,9 @@ SEXP git2r_clone(
     SEXP local_path,
     SEXP bare,
     SEXP branch,
+    SEXP checkout,
     SEXP credentials,
-    SEXP progress);
+    SEXP progress,
+    SEXP proxy_val);
 
 #endif
